@@ -18,6 +18,17 @@ class StrategyRepositoryClient:
 
         return res
 
+
+    async def findStrategyOrdersResult(self, runId:str):
+        # print('findOneStrategyResult', 'runId:', runId)
+
+        res = await self.service.query(QUERIES['FIND_STRATEGY_ORDERS_RESULT'], {
+            'runId': runId
+        })
+
+        return res
+
+
     async def close(self):
         self.service.close()
         self.service.listen_coro.cancelled()
