@@ -38,12 +38,22 @@ QUERIES = {
                 monteCarlo
             }
         }
+        ''',
+
+     'FIND_STRATEGY_ORDERS_RESULT':
+         '''
+    query($runId: String!){
+        findStrategyOrdersResult(runId: $runId) {
+                strategyRunOrders
+                strategyRunOrdersStats
+            }
+        }
         '''
 }
 
 MUTATIONS = {
-    'ENQUEUE_STRATEGY_RUN':
-        '''
+'ENQUEUE_STRATEGY_RUN':
+    '''
         mutation($rootOptions: RootOptionsInput!, $runId: String) {
             enqueueStrategyRun(rootOptions: $rootOptions, runId: $runId) {
                 ''' + JOB_FIELDS + '''
